@@ -734,7 +734,7 @@
 
             outer.append(
                 inner       = $('<div id="xhostplusbox-inner"></div>'),
-                close       = $('<a id="xhostplusbox-close"></a>'),
+                close       = $('<a href="javascript:;" id="xhostplusbox-close"></a>'),
 
                 nav_left    = $('<a href="javascript:;" id="xhostplusbox-left"><span class="fancy-ico" id="xhostplusbox-left-ico"></span></a>'),
                 nav_right   = $('<a href="javascript:;" id="xhostplusbox-right"><span class="fancy-ico" id="xhostplusbox-right-ico"></span></a>')
